/*
 * BQ24295 battery charging driver
 * Copyright Brodersen.
 * 
 * Copyright (C) 2013 Texas Instruments
 */

#ifndef ZEPHYR_DRIVERS_CHARGER_BQ24295_H_
#define ZEPHYR_DRIVERS_CHARGER_BQ24295_H_

/* Register 00h, Input Source Control Register REG00*/
#define BQ2429X_REG00_ISC      		    0x00
#define REG00_ISC_ENHIZ_MASK		    0x80		    //EN_HIZ
#define	REG00_ISC_HIZ_ENABLE			1
#define	REG00_ISC_HIZ_DISABLE			0
#define	REG00_ISC_VINDPM_MASK			0x78		    //Input Voltage Limit
#define	REG00_ISC_VINDPM_BASE			3880
#define	REG00_ISC_VINDPM_LSB			80
#define REG00_ISC_IINLIM_MASK		    0x07		    //Input Current Limit (Actual input current limit is the lower of I2C and ILIM)
#define REG00_ISC_IINLIM_100MA			0
#define REG00_ISC_IINLIM_150MA			1
#define REG00_ISC_IINLIM_500MA			2
#define REG00_ISC_IINLIM_900MA			3
#define REG00_ISC_IINLIM_1000MA			4
#define REG00_ISC_IINLIM_1500MA			5
#define REG00_ISC_IINLIM_2000MA			6
#define REG00_ISC_IINLIM_3000MA			7

/* Register 01h, Power-On Configuration Register REG01*/
#define BQ2429X_REG01_POC	    	    0x01
#define	REG01_POC_REG_RESET_MASK		0x80		    //Register Reset
#define	REG01_POC_REG_RESET				1
#define REG01_POC_WDT_RESET_MASK		0x40		    //I2C Watchdog Timer Reset
#define REG01_POC_WDT_RESET				1
#define REG01_POC_OTG_CONFIG_MASK		0x20		    //Bit[5] Charger Configuration OTG_CONFIG
#define REG01_POC_OTG_DISABLE 			0
#define REG01_POC_OTG_ENABLE 			1 
#define REG01_POC_CHG_CONFIG_MASK     	0x10			//Bit[4] Charger Configuration CHG_CONFIG
#define REG01_POC_CHG_DISABLE        	0
#define REG01_POC_CHG_ENABLE         	1
#define REG01_POC_CHG_OC_CONFIG_MASK    0x30            //Bit[5,4]
#define REG01_POC_CHG_OC_CONFIG_DISABLE 0x0
#define REG01_POC_CHG_OC_CONFIG_CHARGE  0x1
#define REG01_POC_CHG_OC_CONFIG_OTG     0x2
#define REG01_POC_CHG_OC_CONFIG_OTG_ALT 0x3
#define REG01_POC_SYS_MINV_MASK       	0x0E		    //Minimum System Voltage Limit
#define	REG01_POC_SYS_MINV_BASE 		3000
#define REG01_POC_SYS_MINV_LSB			100
#define BQ24295_RESET_MAX_TRIES         100             //User define

/* Register 0x02, Charge Current Control Register REG02*/
#define BQ2429X_REG02_CCC               0x02
#define REG02_CCC_ICHG_MASK           	0xFC		    //Bit[7,2] Fast Charge Current Limit
#define REG02_CCC_ICHG_BASE           	512
#define REG02_CCC_ICHG_LSB            	64
#define REG02_CCC_ICHG_MAX_MA           3008
#define REG02_CCC_BCOLD_MASK			0x02		    //Set Boost Mode temperature monitor threshold voltage to disable boost mode
#define REG02_CCC_BCOLD_M10C			0 
#define REG02_CCC_BCOLD_M20C			1 
#define REG02_CCC_FORCE_20PCT_MASK		0x01		    //Select Fast Charge Current and Pre-Charge Current
#define REG02_CCC_FORCE_20PCT_ENABLE	1 
#define REG02_CCC_FORCE_20PCT_DISABLE	0
 
/* Register 0x03, Pre-Charge/Termination Current Control Register REG03*/
#define BQ2429X_REG03_PCTCC             0x03
#define REG03_PCTCC_IPRECHG_MASK        0xF0		    //Bit[7,4], Pre-Charge Current Limit
#define REG03_PCTCC_IPRECHG_BASE        128
#define REG03_PCTCC_IPRECHG_LSB         128
#define REG03_PCTCC_IPRECHG_MAX_MA      2048
#define REG03_PCTCC_IPRECHG_DEFAULT     256
#define REG03_PCTCC_ITERM_MASK          0x0F		    //Termination Current Limit
#define REG03_PCTCC_ITERM_BASE          128
#define REG03_PCTCC_ITERM_LSB           128
#define REG03_PCTCC_ITERM_MAX_MA        2048
#define REG03_PCTCC_ITERM_DEFAULT       256 

/* Register 0x04, Charge Voltage Control Register REG04*/
#define BQ2429X_REG04_CVC               0x04
#define REG04_CVC_VREG_MASK           	0xFC		    //Bit[7,2], Charge Voltage Limit
#define REG04_CVC_VREG_BASE           	3504
#define REG04_CVC_VREG_LSB            	16
#define REG04_CVC_VREG_OFFSET_MV        3504
#define REG04_CVC_VREG_MIN_MV           REG04_CVC_VREG_OFFSET_MV
#define REG04_CVC_VREG_MAX_MV           4400
#define REG04_CVC_BATLOWV_MASK         	0x02		    //Select pre-charge or fast charge voltage
#define REG04_CVC_BATLOWV_2800MV        0
#define REG04_CVC_BATLOWV_3000MV        1
#define REG04_CVC_VRECHG_MASK         	0x01		    //Battery Recharge Threshold (below battery regulation voltage)
#define REG04_CVC_VRECHG_100MV        	0
#define REG04_CVC_VRECHG_300MV        	1

/* Register 0x05, Charge Termination/Timer Control Register REG05*/
#define BQ2429X_REG05_CTTC             	0x05
#define REG05_CTTC_EN_TERM_MASK        	0x80		    //Charging Termination Enable
#define REG05_CTTC_TERM_ENABLE         	1
#define REG05_CTTC_TERM_DISABLE        	0
#define REG05_CTTC_WDT_MASK            	0x30		    //I2C Watchdog Timer Setting
#define REG05_CTTC_WDT_DISABLE         	0
#define REG05_CTTC_WDT_40S             	40
#define REG05_CTTC_WDT_80S             	80
#define REG05_CTTC_WDT_160S            	160
#define REG05_CTTC_WDT_BASE            	0
#define REG05_CTTC_WDT_LSB             	40
#define REG05_CTTC_EN_TIMER_MASK       	0x08		    //Charging Safety Timer Enable
#define REG05_CTTC_CHG_TIMER_ENABLE    	1
#define REG05_CTTC_CHG_TIMER_DISABLE   	0
#define REG05_CTTC_CHG_TIMER_MASK      	0x06		    //Fast Charge Timer Setting
#define REG05_CTTC_CHG_TIMER_5HOURS    	0
#define REG05_CTTC_CHG_TIMER_8HOURS   	1
#define REG05_CTTC_CHG_TIMER_12HOURS   	2
#define REG05_CTTC_CHG_TIMER_20HOURS   	3

/* Register 0x06, Boost Voltage/Thermal Regulation Control Register REG06*/
#define BQ2429X_REG06_BVTRC             0x06
#define	REG06_BVTRC_BOOSTV_MASK         0xF0            //Boost Voltage setting
#define	REG06_BVTRC_BOOSTV_LSB			64
#define	REG06_BVTRC_BOOSTV_BASE		    4550
#define REG06_BVTRC_BHOT_MASK			0x0C            //Set Boost Mode temperature monitor threshold voltage to disable boost mode
#define REG06_BVTRC_BHOT_55C			0 
#define REG06_BVTRC_BHOT_60C			1 
#define REG06_BVTRC_BHOT_65C			2 
#define REG06_BVTRC_BHOT_DISABLE		3 
#define	REG06_BVTRC_TREG_MASK			0x03            //Thermal Regulation Threshold
#define	REG06_BVTRC_TREG_60C			0
#define	REG06_BVTRC_TREG_80C			1
#define	REG06_BVTRC_TREG_100C			2
#define	REG06_BVTRC_TREG_120C			3

/* Register 0x07, Misc Operation Control Register REG07*/
#define BQ2429X_REG07_MOC               0x07
#define REG07_MOC_FORCE_DPDM_MASK       0x80            //Force DPDM detection
#define REG07_MOC_FORCE_DPDM            1
#define REG07_MOC_TMR2X_EN_MASK         0x40            //Safety Timer Setting during Input DPM and Thermal Regulation
#define REG07_MOC_TMR2X_ENABLE        	1
#define REG07_MOC_TMR2X_DISABLE       	0
#define REG07_MOC_BATFET_DIS_MASK     	0x20            //Force BATFET Off
#define REG07_MOC_BATFET_OFF          	1
#define	REG07_MOC_CHG_FLT_INT_MASK		0x02            //INT on CHRG_FAULT
#define	REG07_MOC_CHG_FLT_INT_DISABLE	0
#define	REG07_MOC_CHG_FLT_INT_ENABLE	1
#define	REG07_MOC_BAT_FLT_INT_MASK		0x01            //INT on BAT_FAULT
#define	REG07_MOC_BAT_FLT_INT_DISABLE	0
#define	REG07_MOC_BAT_FLT_INT_ENABLE	1

/* Register 0x08, System Status Register REG08*/
#define BQ2429X_REG08_SS                0x08
#define REG08_SS_VBUS_STAT_MASK      	0xC0            //VBUS status
#define REG08_SS_VBUS_TYPE_NONE	  	    0
#define REG08_SS_VBUS_TYPE_USB       	1
#define REG08_SS_VBUS_TYPE_ADAPTER   	2
#define REG08_SS_VBUS_TYPE_OTG       	3
#define REG08_SS_CHRG_STAT_MASK      	0x30            //Charging status
#define REG08_SS_CHRG_STAT_IDLE      	0
#define REG08_SS_CHRG_STAT_PRECHG    	1
#define REG08_SS_CHRG_STAT_FASTCHG   	2
#define REG08_SS_CHRG_STAT_CHGDONE   	3
#define	REG08_SS_INDPM_STAT_MASK		0x08            //DPM status
#define	REG08_SS_INDPM_ACTIVE			1
#define REG08_SS_PG_STAT_MASK        	0x04            //Power Good status
#define REG08_SS_POWER_GOOD          	1
#define REG08_SS_THERM_STAT_MASK     	0x02            //Thermal status
#define REG08_SS_IN_THERM_STAT			1
#define REG08_SS_VSYS_STAT_MASK         0x01            //VSYSMIN regulation status
#define REG08_SS_IN_VSYS_STAT           1

/* Register 0x09, New Fault Register REG09*/
#define BQ2429X_REG09_F                 0x09
#define REG09_F_FAULT_WDT_MASK      	0x80            //Watchdog timer expiration indicator
#define REG09_F_FAULT_WDT           	1
#define REG09_F_FAULT_BOOST_MASK    	0x40            //OTG fault indicator
#define REG09_F_FAULT_CHRG_MASK     	0x30            //Charger fault indicator
#define REG09_F_FAULT_CHRG_NORMAL   	0
#define REG09_F_FAULT_CHRG_INPUT    	1
#define REG09_F_FAULT_CHRG_THERMAL  	2
#define REG09_F_FAULT_CHRG_TIMER    	3
#define REG09_F_FAULT_BAT_MASK      	0x08            //Battery fault indicator
#define	REG09_F_FAULT_BAT_OVP			1
#define REG09_F_FAULT_NTC_MASK      	0x03            //Temperature threshold different indicator
#define	REG09_F_FAULT_NTC_NORMAL		0
#define REG09_F_FAULT_NTC_HOT 		    1
#define REG09_F_FAULT_NTC_COLD		    2 

/* Register 0x0A, Vender, Part, Revision Status Register REG0A*/
#define BQ2429X_REG0A_VPRS              0x0A
#define REG0A_VR_PN_MASK             	0xE0            //Vender code
#define REG0A_VR_PN_BQ24295 			6               //BQ24295 
#define REG0A_VR_PN_BQ24296			    1 
#define REG0A_VR_PN_BQ24297			    3 
#define REG0A_VR_DEV_REV_MASK        	0x07            //Reserved

#endif
