/*******************************************************************************
 * Copyright (c) 2024 Brodersen
 *
 *******************************************************************************/

#include "my_charger.h"

#include <zephyr/logging/log.h>
LOG_MODULE_REGISTER(my_charger, LOG_LEVEL_INF);

bool charger_bq24295_read()
{
    charger_prop_t prop;
    union charger_propval val;

    /* I2C1 */
	const struct device *const dev_I2C = DEVICE_DT_GET(DT_ALIAS(i2c1)); 
    if (!device_is_ready(dev_I2C)) {
		LOG_WRN("%s: I2C device not ready.", dev_I2C->name);
		return false;
	} else {
		LOG_INF("%s: I2C device ready.", dev_I2C->name);
	}

	/* Charger bq24295 */
	const struct device *const dev_charger = DEVICE_DT_GET(DT_ALIAS(charger)); 
	if (dev_charger == NULL) {
		LOG_ERR("No device found.");
		return false;
	}

    if (!device_is_ready(dev_charger)) {
		LOG_ERR("%s: charger device not ready.", dev_charger->name);
		return false;
	} else {
		LOG_WRN("%s: charger device ready.", dev_charger->name);
	}

	LOG_INF("Found charger device \"%s\", getting charger data", dev_charger->name);

    prop = CHARGER_PROP_ONLINE;
    if(charger_get_prop(dev_charger, prop, &val) == 0)
        LOG_INF("bq24295 CHARGER_PROP_ONLINE = %s", val.online?"true":"false");
    else
        LOG_ERR("bq24295 CHARGER_PROP_ONLINE read failed!");

    prop = CHARGER_PROP_CHARGE_TYPE;
    if(charger_get_prop(dev_charger, prop, &val) == 0)
        LOG_INF("bq24295 CHARGER_PROP_CHARGE_TYPE = %d(TRICKLE 2, FAST 3, STANDARD 4)", val.charge_type);
    else
        LOG_ERR("bq24295 CHARGER_PROP_CHARGE_TYPE read failed!");

    prop = CHARGER_PROP_HEALTH;
    if(charger_get_prop(dev_charger, prop, &val) == 0)
        LOG_INF("bq24295 CHARGER_PROP_HEALTH = %d(GOOD 1, OVERHEAT 2, OVERVOLTAGE 3)", val.health);
    else
        LOG_ERR("bq24295 CHARGER_PROP_HEALTH read failed!");

    prop = CHARGER_PROP_STATUS;
    if(charger_get_prop(dev_charger, prop, &val) == 0)
        LOG_INF("bq24295 CHARGER_PROP_STATUS = %d(CHARGING 1, DISCHARGING 2, NOT_CHARGING 3, FULL 4)", val.status);
    else
        LOG_ERR("bq24295 CHARGER_PROP_STATUS read failed!");  

    prop = CHARGER_PROP_CONSTANT_CHARGE_CURRENT_UA;
    if(charger_get_prop(dev_charger, prop, &val) == 0)
        LOG_INF("bq24295 CHARGER_PROP_CONSTANT_CHARGE_CURRENT_UA = %u", val.const_charge_current_ua);
    else
        LOG_ERR("bq24295 CHARGER_PROP_CONSTANT_CHARGE_CURRENT_UA read failed!");

    prop = CHARGER_PROP_CONSTANT_CHARGE_VOLTAGE_UV;
    if(charger_get_prop(dev_charger, prop, &val) == 0)
        LOG_INF("bq24295 CHARGER_PROP_CONSTANT_CHARGE_VOLTAGE_UV = %u", val.const_charge_voltage_uv);
    else
        LOG_ERR("bq24295 CHARGER_PROP_CONSTANT_CHARGE_VOLTAGE_UV read failed!");  

    prop = CHARGER_PROP_PRECHARGE_CURRENT_UA;
    if(charger_get_prop(dev_charger, prop, &val) == 0)
        LOG_INF("bq24295 CHARGER_PROP_PRECHARGE_CURRENT_UA = %u", val.precharge_current_ua);
    else
        LOG_ERR("bq24295 CHARGER_PROP_PRECHARGE_CURRENT_UA read failed!");  

    prop = CHARGER_PROP_CHARGE_TERM_CURRENT_UA;
    if(charger_get_prop(dev_charger, prop, &val) == 0)
        LOG_INF("bq24295 CHARGER_PROP_CHARGE_TERM_CURRENT_UA = %u", val.charge_term_current_ua);
    else
        LOG_ERR("bq24295 CHARGER_PROP_CHARGE_TERM_CURRENT_UA read failed!");      

    prop = CHARGER_PROP_HIZ_MODE;
    if(charger_get_prop(dev_charger, prop, &val) == 0)
        LOG_INF("bq24295 CHARGER_PROP_HIZ_MODE = %s", val.hiz_mode?"true":"false");
    else
        LOG_ERR("bq24295 CHARGER_PROP_HIZ_MODE read failed!");  

    prop = CHARGER_PROP_REG01;
    if(charger_get_prop(dev_charger, prop, &val) == 0)
        LOG_INF("bq24295 CHARGER_PROP_REG01 = 0x%x", val.reg_value);
    else
        LOG_ERR("bq24295 CHARGER_PROP_REG01 read failed!");        
	
    return true;
}